All Classes and Interfaces
Class
Description
An AWS Arn.
An augmented manifest file that provides training data for your custom model.
The result of calling the operation.
BatchDetectDominantLanguageRequest Marshaller
The result of calling the operation.
BatchDetectEntitiesRequest Marshaller
The result of calling the operation.
BatchDetectKeyPhrasesRequest Marshaller
The result of calling the operation.
BatchDetectSentimentRequest Marshaller
The result of calling the operation.
BatchDetectSyntaxRequest Marshaller
Analysis results for one of the documents in the batch.
BatchDetectTargetedSentimentRequest Marshaller
Describes an error that occurred while processing a document in a batch.
The number of documents in the request exceeds the limit of 25.
Information about each word or line of text in the input document.
A reference to a block.
The bounding box around the detected page or around an element on a document page.
Nested block contained within a block.
Describes the result metrics for the test data associated with an documentation classifier.
Provides information about a document classifier.
ClassifyDocumentRequest MarshallerService client for accessing Amazon Comprehend asynchronously.
A builder for creating an instance of
ComprehendAsyncClient.The parameters object used to resolve the auth schemes for the Comprehend service.
A builder for a
ComprehendAuthSchemeParams.An auth scheme provider for Comprehend service.
This includes configuration specific to Amazon Comprehend that is supported by both
ComprehendClientBuilder
and ComprehendAsyncClientBuilder.Service client for accessing Amazon Comprehend.
A builder for creating an instance of
ComprehendClient.The parameters object used to resolve an endpoint for the Comprehend service.
An endpoint provider for Comprehend.
Class to expose the service client settings to the user.
A builder for creating a
ComprehendServiceClientConfiguration
Concurrent modification of the tags associated with an Amazon Comprehend resource is not supported.
ContainsPiiEntitiesRequest MarshallerCreateDatasetRequest MarshallerCreateDocumentClassifierRequest MarshallerCreateEndpointRequest MarshallerCreateEntityRecognizerRequest MarshallerCreateFlywheelRequest Marshaller
Data security configuration.
An augmented manifest file that provides training data for your custom model.
Describes the dataset input data configuration for a document classifier model.
Describes the annotations associated with a entity recognizer.
Describes the documents submitted with a dataset for an entity recognizer model.
Describes the dataset entity list for an entity recognizer model.
Specifies the format and location of the input data.
Filter the datasets based on creation time or dataset status.
Specifies the format and location of the input data for the dataset.
Properties associated with the dataset.
DeleteDocumentClassifierRequest MarshallerDeleteEndpointRequest MarshallerDeleteEntityRecognizerRequest MarshallerDeleteFlywheelRequest MarshallerDeleteResourcePolicyRequest MarshallerDescribeDatasetRequest MarshallerDescribeDocumentClassificationJobRequest MarshallerDescribeDocumentClassifierRequest MarshallerDescribeDominantLanguageDetectionJobRequest MarshallerDescribeEndpointRequest MarshallerDescribeEntitiesDetectionJobRequest MarshallerDescribeEntityRecognizerRequest MarshallerDescribeEventsDetectionJobRequest MarshallerDescribeFlywheelIterationRequest MarshallerDescribeFlywheelRequest MarshallerDescribeKeyPhrasesDetectionJobRequest MarshallerDescribePiiEntitiesDetectionJobRequest MarshallerDescribeResourcePolicyRequest MarshallerDescribeSentimentDetectionJobRequest MarshallerDescribeTargetedSentimentDetectionJobRequest MarshallerDescribeTopicsDetectionJobRequest MarshallerDetectDominantLanguageRequest MarshallerDetectEntitiesRequest MarshallerDetectKeyPhrasesRequest MarshallerDetectPiiEntitiesRequest MarshallerDetectSentimentRequest MarshallerDetectSyntaxRequest MarshallerDetectTargetedSentimentRequest MarshallerDetectToxicContentRequest Marshaller
Specifies the class that categorizes the document being analyzed
Configuration required for a document classification model.
Provides information for filtering a list of document classification jobs.
Provides information about a document classification job.
The location of the training documents.
Provides information for filtering a list of document classifiers.
The input properties for training a document classifier.
Provide the location for output data from a custom classifier job.
Provides information about a document classifier.
Describes information about a document classifier and its versions.
Specifies one of the label or labels that categorize the document being analyzed.
Information about the document, discovered during text extraction.
Provides configuration parameters to override the default actions for extracting text from PDF documents and image
files.
TABLES or FORMS
Document type for each page in the document.
Returns the code for the dominant language in the input text and the level of confidence that Amazon Comprehend has
in the accuracy of the detection.
Provides information for filtering a list of dominant language detection jobs.
Provides information about a dominant language detection job.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
The filter used to determine which endpoints are returned.
Specifies information about the specified endpoint.
Provides information for filtering a list of dominant language detection jobs.
Provides information about an entities detection job.
Provides information about an entity.
Specifies one of the label or labels that categorize the personally identifiable information (PII) entity being
analyzed.
Configuration required for an entity recognition model.
Describes the annotations associated with a entity recognizer.
Describes the training documents submitted with an entity recognizer.
Describes the entity list submitted with an entity recognizer.
Detailed information about the accuracy of an entity recognizer.
Provides information for filtering a list of entity recognizers.
Specifies the format and location of the input data.
Detailed information about an entity recognizer.
Individual item from the list of entity types in the metadata of an entity recognizer.
Output data configuration.
Describes information about an entity recognizer.
Describes the information about an entity recognizer and its versions.
Detailed information about the accuracy of an entity recognizer for a specific entity type.
An entity type within a labeled training dataset that Amazon Comprehend uses to train a custom entity recognizer.
Text extraction encountered one or more page-level errors in the input document.
Provides information for filtering a list of event detection jobs.
Provides information about an events detection job.
Array of the number of characters extracted from each page.
Filter the flywheels based on creation time or flywheel status.
Filter the flywheel iterations based on creation time.
The configuration properties of a flywheel iteration.
The evaluation metrics associated with the evaluated model.
The flywheel properties.
Flywheel summary information.
Information about the location of items on a document page.
Identifiers for variables declared within the rule engine, e.g.
ImportModelRequest Marshaller
The input properties for an inference job.
An internal server error occurred.
The filter specified for the operation is invalid.
Provides additional detail about why the request failed.
The request is invalid.
The specified job was not found.
Describes a key noun phrase.
Provides information for filtering a list of dominant language detection jobs.
Provides information about a key phrases detection job.
The KMS customer managed key (CMK) entered cannot be validated.
Represents the output for the
ComprehendClient.listDatasetsPaginator(software.amazon.awssdk.services.comprehend.model.ListDatasetsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listDatasetsPaginator(software.amazon.awssdk.services.comprehend.model.ListDatasetsRequest)
operation which is a paginated operation.ListDatasetsRequest Marshaller
Represents the output for the
ComprehendClient.listDocumentClassificationJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassificationJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listDocumentClassificationJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassificationJobsRequest)
operation which is a paginated operation.ListDocumentClassificationJobsRequest Marshaller
Represents the output for the
ComprehendClient.listDocumentClassifiersPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassifiersRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listDocumentClassifiersPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassifiersRequest)
operation which is a paginated operation.ListDocumentClassifiersRequest Marshaller
Represents the output for the
ComprehendClient.listDocumentClassifierSummariesPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassifierSummariesRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listDocumentClassifierSummariesPaginator(software.amazon.awssdk.services.comprehend.model.ListDocumentClassifierSummariesRequest)
operation which is a paginated operation.ListDocumentClassifierSummariesRequest Marshaller
Represents the output for the
ComprehendClient.listDominantLanguageDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListDominantLanguageDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listDominantLanguageDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListDominantLanguageDetectionJobsRequest)
operation which is a paginated operation.ListDominantLanguageDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listEndpointsPaginator(software.amazon.awssdk.services.comprehend.model.ListEndpointsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listEndpointsPaginator(software.amazon.awssdk.services.comprehend.model.ListEndpointsRequest)
operation which is a paginated operation.ListEndpointsRequest Marshaller
Represents the output for the
ComprehendClient.listEntitiesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListEntitiesDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listEntitiesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListEntitiesDetectionJobsRequest)
operation which is a paginated operation.ListEntitiesDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listEntityRecognizersPaginator(software.amazon.awssdk.services.comprehend.model.ListEntityRecognizersRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listEntityRecognizersPaginator(software.amazon.awssdk.services.comprehend.model.ListEntityRecognizersRequest)
operation which is a paginated operation.ListEntityRecognizersRequest Marshaller
Represents the output for the
ComprehendClient.listEntityRecognizerSummariesPaginator(software.amazon.awssdk.services.comprehend.model.ListEntityRecognizerSummariesRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listEntityRecognizerSummariesPaginator(software.amazon.awssdk.services.comprehend.model.ListEntityRecognizerSummariesRequest)
operation which is a paginated operation.ListEntityRecognizerSummariesRequest Marshaller
Represents the output for the
ComprehendClient.listEventsDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListEventsDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listEventsDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListEventsDetectionJobsRequest)
operation which is a paginated operation.ListEventsDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listFlywheelIterationHistoryPaginator(software.amazon.awssdk.services.comprehend.model.ListFlywheelIterationHistoryRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listFlywheelIterationHistoryPaginator(software.amazon.awssdk.services.comprehend.model.ListFlywheelIterationHistoryRequest)
operation which is a paginated operation.ListFlywheelIterationHistoryRequest Marshaller
Represents the output for the
ComprehendClient.listFlywheelsPaginator(software.amazon.awssdk.services.comprehend.model.ListFlywheelsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listFlywheelsPaginator(software.amazon.awssdk.services.comprehend.model.ListFlywheelsRequest)
operation which is a paginated operation.ListFlywheelsRequest Marshaller
Represents the output for the
ComprehendClient.listKeyPhrasesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListKeyPhrasesDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listKeyPhrasesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListKeyPhrasesDetectionJobsRequest)
operation which is a paginated operation.ListKeyPhrasesDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listPiiEntitiesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListPiiEntitiesDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listPiiEntitiesDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListPiiEntitiesDetectionJobsRequest)
operation which is a paginated operation.ListPiiEntitiesDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listSentimentDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListSentimentDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listSentimentDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListSentimentDetectionJobsRequest)
operation which is a paginated operation.ListSentimentDetectionJobsRequest MarshallerListTagsForResourceRequest Marshaller
Represents the output for the
ComprehendClient.listTargetedSentimentDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListTargetedSentimentDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listTargetedSentimentDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListTargetedSentimentDetectionJobsRequest)
operation which is a paginated operation.ListTargetedSentimentDetectionJobsRequest Marshaller
Represents the output for the
ComprehendClient.listTopicsDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest)
operation which is a paginated operation.
Represents the output for the
ComprehendAsyncClient.listTopicsDetectionJobsPaginator(software.amazon.awssdk.services.comprehend.model.ListTopicsDetectionJobsRequest)
operation which is a paginated operation.ListTopicsDetectionJobsRequest Marshaller
Contains the sentiment and sentiment score for one mention of an entity.
Provides configuration parameters for the output of inference jobs.
Identifies the part of speech represented by the token and gives the confidence that Amazon Comprehend has that the
part of speech was correctly identified.
Provides information for filtering a list of PII entity detection jobs.
Provides information about a PII entities detection job.
Provides information about a PII entity.
Provides configuration parameters for the output of PII entity detection jobs.
The X and Y coordinates of a point on a document page.
PutResourcePolicyRequest Marshaller
Provides configuration parameters for PII entity redaction.
List of child blocks for the current block.
The specified resource name is already in use.
The maximum number of resources per account has been exceeded.
The specified resource ARN was not found.
The specified resource is not available.
Represents a URL to be used internally for endpoint resolution.
Provides information for filtering a list of dominant language detection jobs.
Provides information about a sentiment detection job.
Describes the level of confidence that Amazon Comprehend has in the accuracy of its detection of sentiments.
StartDocumentClassificationJobRequest MarshallerStartDominantLanguageDetectionJobRequest MarshallerStartEntitiesDetectionJobRequest MarshallerStartEventsDetectionJobRequest MarshallerStartFlywheelIterationRequest MarshallerStartKeyPhrasesDetectionJobRequest MarshallerStartPiiEntitiesDetectionJobRequest MarshallerStartSentimentDetectionJobRequest MarshallerStartTargetedSentimentDetectionJobRequest MarshallerStartTopicsDetectionJobRequest MarshallerStopDominantLanguageDetectionJobRequest MarshallerStopEntitiesDetectionJobRequest MarshallerStopEventsDetectionJobRequest MarshallerStopKeyPhrasesDetectionJobRequest MarshallerStopPiiEntitiesDetectionJobRequest MarshallerStopSentimentDetectionJobRequest MarshallerStopTargetedSentimentDetectionJobRequest MarshallerStopTrainingDocumentClassifierRequest MarshallerStopTrainingEntityRecognizerRequest Marshaller
Represents a work in the input text that was recognized and assigned a part of speech.
A key-value pair that adds as a metadata to a resource used by Amazon Comprehend.
TagResourceRequest Marshaller
Provides information for filtering a list of dominant language detection jobs.
Provides information about a targeted sentiment detection job.
Information about one of the entities found by targeted sentiment analysis.
Information about one mention of an entity.
Configuration about the model associated with a flywheel.
One of the of text strings.
The size of the input text exceeds the limit.
The number of requests exceeds the limit.
The request contains more tag keys than can be associated with a resource (50 tag keys per resource).
The request contains more tags than can be associated with a resource (50 tags per resource).
Provides information for filtering topic detection jobs.
Provides information about a topic detection job.
Toxic content analysis result for one string.
Toxicity analysis result for one string.
Amazon Comprehend can't process the language of the input text.
UntagResourceRequest Marshaller
Data security configuration.
UpdateEndpointRequest MarshallerUpdateFlywheelRequest MarshallerBase class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using
for the job.
The system identified one of the following warnings while processing the input document: